@@ -397,9 +397,9 @@ updatedHtest = function(object, ...) {
     } else if(n == 1) {
       ## need another
       cat("Need another\n")
-#      x$data.name = Paste(id(dataVarList[[1]])," and Drop variable here")
-      tmp = Paste(id(dataVarList[[1]])," and Drop variable here")
-      svalue(object.list[["data.name"]]) <-  format(tmp)
+      x$data.name = Paste(id(dataVarList[[1]])," and Drop variable here")
+#      tmp = Paste(id(dataVarList[[1]])," and Drop variable here")
+#      svalue(object.list[["data.name"]]) <- format(tmp)
     } else  {                           # n > 1
       theXName = id(dataVarList[[n-1]])
       theXValues = svalue(dataVarList[[n-1]])
@@ -604,11 +604,11 @@ dHtest = function(x, type=NULL, digits = 4, container = NULL, ...) {
   object.list = list()
   for(i in passiveComponents) {
     object.list[[i]] = glabel("*")
-    font(object.list[[i]]) <-list(color="red")
+    font(object.list[[i]]) <- c(color="red")
   }
   for(i in activeComponents) {
     object.list[[i]] = glabel("*", editable=TRUE)
-    font(object.list[[i]]) <-  list(style="bold")
+    font(object.list[[i]]) <-  c(style="bold")
   }
 
   ## override
