@@ -280,12 +280,12 @@
         glabel("x=",cont=varGroup)
         xVar = glabel("x-variable", cont=varGroup,editable=TRUE)
         adddroptarget(xVar)
-        font(xVar) <-  list(style="bold")
+        font(xVar) <-  c(style="bold")
         glabel(", ", cont=varGroup)
         glabel("y=",cont=varGroup)
         yVar = glabel("y-variable", cont=varGroup,editable=TRUE)
         adddroptarget(yVar)
-        font(yVar) <-  list(style="bold")
+        font(yVar) <-  c(style="bold")
         useSelected = gcheckbox("consider selected values only",cont=spframe)
         bgroup = ggroup(cont=gp)
         gbutton("Add regression line",cont=bgroup,
